summaryrefslogtreecommitdiff
path: root/src/common/manaserv_protocol.h
diff options
context:
space:
mode:
authorErik Schilling <ablu.erikschilling@googlemail.com>2013-09-15 13:35:35 +0200
committerErik Schilling <ablu.erikschilling@googlemail.com>2013-09-15 13:35:35 +0200
commit6de8fd28ecb23dccded9c3eabed2f80cde7eb122 (patch)
treebff3d63e9f3c6753e7fe56372c48e06e69314537 /src/common/manaserv_protocol.h
parentd15190dc8cd8258fcdf06bb615de80bc97a5ac20 (diff)
downloadmanaserv-6de8fd28ecb23dccded9c3eabed2f80cde7eb122.tar.gz
manaserv-6de8fd28ecb23dccded9c3eabed2f80cde7eb122.tar.bz2
manaserv-6de8fd28ecb23dccded9c3eabed2f80cde7eb122.tar.xz
manaserv-6de8fd28ecb23dccded9c3eabed2f80cde7eb122.zip
Fixed handling of reconnects while the old connection is still valid
The old connection is now terminated. And the new connection will receive the character data properly.
Diffstat (limited to 'src/common/manaserv_protocol.h')
-rw-r--r--src/common/manaserv_protocol.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/common/manaserv_protocol.h b/src/common/manaserv_protocol.h
index 2bfd8c70..411b08ca 100644
--- a/src/common/manaserv_protocol.h
+++ b/src/common/manaserv_protocol.h
@@ -308,7 +308,8 @@ enum {
ERRMSG_TIME_OUT, // data failed to arrive in due time
ERRMSG_LIMIT_REACHED, // limit reached
ERRMSG_ADMINISTRATIVE_LOGOFF, // kicked by server administrator
- ERRMSG_ALREADY_MEMBER // is already member of guild/party
+ ERRMSG_ALREADY_MEMBER, // is already member of guild/party
+ ERRMSG_LOGIN_WAS_TAKEN_OVER // a different connection took over
};
// used in AGMSG_REGISTER_RESPONSE to show state of item db